==> ARDB-1.40.tar.gz: ARDB-1.40/lib/ACIS/UserData/Data/Record.pm <==
package ACIS::UserData::Data::Record;

use strict;
use vars qw( @ISA );

@ISA = qw( ARDB::Record );

sub id
 {
  my $self = shift;
  
  return $self -> {'handle'};
 }
#   /.

sub type
 {
  return 'acis-record-person';
 }
#   .

sub get_value
 {
  my $data = shift;
  my $path  = shift;
  
  my @path  = split '/', $path;
  foreach (@path)
   {
    $data = $data -> {$_};
   }
  return $data;
 }

#      ,  
# SPEC   .  SPEC   
# ARDB.      XPath,  author/name,
#   -    -    -- 
# ,      - .

# ,  ARDB  get_unfolded_record() 

sub add_relationship( RELATION, ANOTHER_OBJECT )
 {
  my $self     = shift;
  my $relation = shift;
  my $object   = shift;
  
  $relations = $self -> {'ardb-record'} -> {'relations'};
  
  if (ref $relations -> {$relation} eq 'ARRAY')
   {
    push @{$relations -> {$relation}}, $object;
   }
  else
   {
    $relations -> {$relation} = [];
    push @{$relations -> {$relation}}, $object;
   } 
 }

#      .   ,
#   ARDB    
#   ,       
# - ...       --  
#  .

sub set_view
 {
  my $self = shift;
  my $view = shift;
  
  $self -> {'ardb-record'} -> {'view'} = $view;
 }
#  "" ,      
# .

#  
sub view
 {
  my $self = shift;
  
  return $self -> {'ardb-record'} -> {'view'};
 }
#    ,     . 
# .

sub get_relationship
 {
  my $self     = shift;
  my $relation = shift;
  
  $relations = $self -> {'ardb-record'} -> {'relations'};
  
  if (ref $relations -> {$relation} eq 'ARRAY')
   {
    return @{$relations -> {$relation}};
   }
  else
   {
    return undef;
   } 
 }
#    ,     
# .   .

==> ARDB-1.47.tar.gz: ARDB-1.47/lib/ACIS/UserData/Data/Record.pm <==
package ACIS::UserData::Data::Record;

use strict;

use base ( 'ARDB::Record' );

sub id
 {
  my $self = shift;
  
  return $self -> {'handle'};
 }
#   /.

sub type
 {
  return 'acis-record-person';
 }
#   .

sub get_value
 {
  my $data = shift;
  my $path  = shift;
  
  my @path  = split '/', $path;
  foreach (@path)
   {
    $data = $data -> {$_};
   }
  
  if (ref $data eq 'ARRAY')
   { return @$data; }
   
  return $data;
 }

#      ,  
# SPEC   .  SPEC   
# ARDB.      XPath,  author/name,
#   -    -    -- 
# ,      - .

# ,  ARDB  get_unfolded_record() 

sub add_relationship
 {
  my $self     = shift;
  my $relation = shift;
  my $object   = shift;
  
  my $relations = $self -> {'ardb-record'} -> {'relations'};
  
  if (ref $relations -> {$relation} eq 'ARRAY')
   {
    push @{$relations -> {$relation}}, $object;
   }
  else
   {
    $relations -> {$relation} = [];
    push @{$relations -> {$relation}}, $object;
   } 
 }

#      .   ,
#   ARDB    
#   ,       
# - ...       --  
#  .

sub set_view
 {
  my $self = shift;
  my $view = shift;
  
  $self -> {'ardb-record'} -> {'view'} = $view;
 }
#  "" ,      
# .

#  
sub view
 {
  my $self = shift;
  
  return $self -> {'ardb-record'} -> {'view'};
 }
#    ,     . 
# .

sub get_relationship
 {
  my $self     = shift;
  my $relation = shift;
  
  my $relations = $self -> {'ardb-record'} -> {'relations'};
  
  if (ref $relations -> {$relation} eq 'ARRAY')
   {
    return @{$relations -> {$relation}};
   }
  else
   {
    return undef;
   } 
 }
#    ,     
# .   .
1;
